Class: Google::Apis::BlockchainnodeengineV1::BlockchainNodeEngineService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::BlockchainnodeengineV1::BlockchainNodeEngineService
- Defined in:
- lib/google/apis/blockchainnodeengine_v1/service.rb
Overview
Blockchain Node Engine API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://blockchainnodeengine.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_blockchain_node(parent, blockchain_node_object = nil, blockchain_node_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::Operation
Creates a new blockchain node in a given project and location.
-
#delete_project_location_blockchain_node(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::Operation
Deletes a single blockchain node.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::GoogleProtobufEmpty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::Location
Gets information about a location.
-
#get_project_location_blockchain_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::BlockchainNode
Gets details of a single blockchain node.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ BlockchainNodeEngineService
constructor
A new instance of BlockchainNodeEngineService.
-
#list_project_location_blockchain_nodes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::ListBlockchainNodesResponse
Lists blockchain nodes in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_blockchain_node(name, blockchain_node_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::Operation
Updates the parameters of a single blockchain node.
Constructor Details
#initialize ⇒ BlockchainNodeEngineService
Returns a new instance of BlockchainNodeEngineService.
47 48 49 50 51 52 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-blockchainnodeengine_v1', client_version: Google::Apis::BlockchainnodeengineV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 377 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::BlockchainnodeengineV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::BlockchainnodeengineV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::BlockchainnodeengineV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_blockchain_node(parent, blockchain_node_object = nil, blockchain_node_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::Operation
Creates a new blockchain node in a given project and location.
165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 165 def create_project_location_blockchain_node(parent, blockchain_node_object = nil, blockchain_node_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/blockchainNodes', ) command.request_representation = Google::Apis::BlockchainnodeengineV1::BlockchainNode::Representation command.request_object = blockchain_node_object command.response_representation = Google::Apis::BlockchainnodeengineV1::Operation::Representation command.response_class = Google::Apis::BlockchainnodeengineV1::Operation command.params['parent'] = parent unless parent.nil? command.query['blockchainNodeId'] = blockchain_node_id unless blockchain_node_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_blockchain_node(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::Operation
Deletes a single blockchain node.
211 212 213 214 215 216 217 218 219 220 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 211 def delete_project_location_blockchain_node(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BlockchainnodeengineV1::Operation::Representation command.response_class = Google::Apis::BlockchainnodeengineV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::GoogleProtobufEmpty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
412 413 414 415 416 417 418 419 420 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 412 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BlockchainnodeengineV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::BlockchainnodeengineV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BlockchainnodeengineV1::Location::Representation command.response_class = Google::Apis::BlockchainnodeengineV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_blockchain_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::BlockchainNode
Gets details of a single blockchain node.
243 244 245 246 247 248 249 250 251 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 243 def get_project_location_blockchain_node(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BlockchainnodeengineV1::BlockchainNode::Representation command.response_class = Google::Apis::BlockchainnodeengineV1::BlockchainNode command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
443 444 445 446 447 448 449 450 451 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 443 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BlockchainnodeengineV1::Operation::Representation command.response_class = Google::Apis::BlockchainnodeengineV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_blockchain_nodes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::ListBlockchainNodesResponse
Lists blockchain nodes in a given project and location.
282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 282 def list_project_location_blockchain_nodes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/blockchainNodes', ) command.response_representation = Google::Apis::BlockchainnodeengineV1::ListBlockchainNodesResponse::Representation command.response_class = Google::Apis::BlockchainnodeengineV1::ListBlockchainNodesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 480 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::BlockchainnodeengineV1::ListOperationsResponse::Representation command.response_class = Google::Apis::BlockchainnodeengineV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::ListLocationsResponse
Lists information about the supported locations for this service.
117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 117 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::BlockchainnodeengineV1::ListLocationsResponse::Representation command.response_class = Google::Apis::BlockchainnodeengineV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_blockchain_node(name, blockchain_node_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BlockchainnodeengineV1::Operation
Updates the parameters of a single blockchain node.
335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/google/apis/blockchainnodeengine_v1/service.rb', line 335 def patch_project_location_blockchain_node(name, blockchain_node_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BlockchainnodeengineV1::BlockchainNode::Representation command.request_object = blockchain_node_object command.response_representation = Google::Apis::BlockchainnodeengineV1::Operation::Representation command.response_class = Google::Apis::BlockchainnodeengineV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |